# 평소 귀찮았거나 불편했던 것들을 모아놓은 라이브러리
print를 더욱 편리하고 잘 꾸밀수있도록 도와주는 라이브러리!
또한, 함수 설명이 한글로 되어있어 한국인 친화적인 라이브러리!
(이외의 기능은 차후 추가 예정)

---

## printd
printd는 print를 꾸며주는(decorate)해주는 기능이다. 주요 기능은
- 글자에 색 입히기
기존 ANSI color코드를 원래내용 양쪽에 붙여야 하고 `\e[0;31m`처럼 숫자만 봐서는 색을 유추하기 힘든 문제가 있다.
하지만 이 support-dh를 쓴다면 
`printd('text', color='color')`를 통해 색을 더 직관적이게 알 수 있고, 사용하기에도 유용해 코드를 만드는것이 편리해질수 있다.
- 색에 기울임, 굵은 글씨 등의 추가 효과를 입히기
    `printd('text', more_parameter=['function'])`을 통해 굵은 글씨, 밑줄 등을 첨가하여 더욱 글자를 꾸미기 용이해 질 것이다.

## \*sort 기능 추가
sort 알고리즘 현제`4`종 제공중
- counting sort, bogo sort, radix sort, quick sort
- 알고리즘_이름(list) -> 정렬해줌



~~수행평가를 위해 제작된 라이브러리 입니다.~~